@@ -1,23 +1,15 @@
-from typing import TYPE_CHECKING, Optional
+from typing import TYPE_CHECKING
 
 from cloudfoundry_client.json_object import JsonObject
-from cloudfoundry_client.v3.entities import EntityManager, Entity
+from cloudfoundry_client.v3.entities import EntityManager
 
 if TYPE_CHECKING:
     from cloudfoundry_client.client import CloudFoundryClient
 
 
-class App(Entity):
-    @staticmethod
-    def _manager_method(link_name: str, link_method: str) -> Optional[str]:
-        if link_name == "environment_variables" and link_method == "get":
-            return "_get"  # instead of _paginate
-        return Entity._manager_method(link_name, link_method)
-
-
 class AppManager(EntityManager):
     def __init__(self, target_endpoint: str, client: "CloudFoundryClient"):
-        super(AppManager, self).__init__(target_endpoint, client, "/v3/apps", App)
+        super(AppManager, self).__init__(target_endpoint, client, "/v3/apps")
 
     def restart(self, application_guid: str):
         return super(AppManager, self)._post("%s%s/%s/actions/restart" % (self.target_endpoint,
